@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "knotefinddialog.h"
 #include "widget/notelistwidget.h"
 
-#include <AkonadiSearch/PIM/notequery.h>
-#include <AkonadiSearch/PIM/resultiterator.h>
+#include <PIM/notequery.h>
+#include <PIM/resultiterator.h>
 
 #include <KLocalizedString>
 #include <QIcon>
@@ -98,9 +98,7 @@ KNoteFindWidget::KNoteFindWidget(QWidget *parent)
     mSearchLineEdit->setFocus();
 }
 
-KNoteFindWidget::~KNoteFindWidget()
-{
-}
+KNoteFindWidget::~KNoteFindWidget() = default;
 
 void KNoteFindWidget::setExistingNotes(const QHash<Akonadi::Item::Id, Akonadi::Item> &notes)
 {
@@ -112,15 +110,46 @@ void KNoteFindWidget::slotItemDoubleClicked(QListWidgetItem *item)
     Q_EMIT noteSelected(mNoteList->itemId(item));
 }
 
+// code from kitinerary/src/lib/stringutil.cpp
+static QString normalize(QStringView str)
+{
+    QString out;
+    out.reserve(str.size());
+    for (const auto c : str) {
+        // case folding
+        const auto n = c.toCaseFolded();
+
+        // if the character has a canonical decomposition use that and skip the
+        // combining diacritic markers following it
+        // see https://en.wikipedia.org/wiki/Unicode_equivalence
+        // see https://en.wikipedia.org/wiki/Combining_character
+        if (n.decompositionTag() == QChar::Canonical) {
+            out.push_back(n.decomposition().at(0));
+        }
+        // handle compatibility compositions such as ligatures
+        // see https://en.wikipedia.org/wiki/Unicode_compatibility_characters
+        else if (n.decompositionTag() == QChar::Compat && n.isLetter() && n.script() == QChar::Script_Latin) {
+            out.append(n.decomposition());
+        } else {
+            out.push_back(n);
+        }
+    }
+    return out;
+}
+
 void KNoteFindWidget::slotSearchNote()
 {
     const QString searchStr = mSearchLineEdit->text().trimmed();
     if (searchStr.trimmed().isEmpty()) {
         return;
     }
+    auto config = KConfig(QStringLiteral("akonadi_indexing_agent"));
+    KConfigGroup cfg = config.group("General");
+    const bool respectDiacriticAndAccents = cfg.readEntry("respectDiacriticAndAccents", true);
+    const QString searchString = respectDiacriticAndAccents ? searchStr : normalize(searchStr);
     Akonadi::Search::PIM::NoteQuery query;
-    query.matchNote(searchStr);
-    query.matchTitle(searchStr);
+    query.matchNote(searchString);
+    query.matchTitle(searchString);
 
     Akonadi::Search::PIM::ResultIterator it = query.exec();
 
