@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,18 +21,12 @@
 #include "knotes_debug.h"
 #include <KLocalizedString>
 
-#include <grantlee/context.h>
-#include <grantlee/engine.h>
-#include <grantlee/templateloader.h>
-
 KNotePrinter::KNotePrinter(QObject *parent)
     : QObject(parent)
 {
 }
 
-KNotePrinter::~KNotePrinter()
-{
-}
+KNotePrinter::~KNotePrinter() = default;
 
 void KNotePrinter::setDefaultFont(const QFont &font)
 {
